
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "dh-enum-types.h"
#include "devhelp.h"
#include "dh-application-window.h"
#include "dh-assistant-view.h"
#include "dh-book.h"
#include "dh-book-list.h"
#include "dh-book-list-builder.h"
#include "dh-book-list-directory.h"
#include "dh-book-manager.h"
#include "dh-book-tree.h"
#include "dh-completion.h"
#include "dh-init.h"
#include "dh-keyword-model.h"
#include "dh-link.h"
#include "dh-notebook.h"
#include "dh-profile.h"
#include "dh-profile-builder.h"
#include "dh-search-bar.h"
#include "dh-settings.h"
#include "dh-settings-builder.h"
#include "dh-sidebar.h"
#include "dh-tab.h"
#include "dh-tab-label.h"
#include "dh-web-view.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "dh-link.h" */

GType
dh_link_type_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (DH_LINK_TYPE_BOOK), "DH_LINK_TYPE_BOOK", "book" },
        { C_ENUM (DH_LINK_TYPE_PAGE), "DH_LINK_TYPE_PAGE", "page" },
        { C_ENUM (DH_LINK_TYPE_KEYWORD), "DH_LINK_TYPE_KEYWORD", "keyword" },
        { C_ENUM (DH_LINK_TYPE_FUNCTION), "DH_LINK_TYPE_FUNCTION", "function" },
        { C_ENUM (DH_LINK_TYPE_STRUCT), "DH_LINK_TYPE_STRUCT", "struct" },
        { C_ENUM (DH_LINK_TYPE_MACRO), "DH_LINK_TYPE_MACRO", "macro" },
        { C_ENUM (DH_LINK_TYPE_ENUM), "DH_LINK_TYPE_ENUM", "enum" },
        { C_ENUM (DH_LINK_TYPE_TYPEDEF), "DH_LINK_TYPE_TYPEDEF", "typedef" },
        { C_ENUM (DH_LINK_TYPE_PROPERTY), "DH_LINK_TYPE_PROPERTY", "property" },
        { C_ENUM (DH_LINK_TYPE_SIGNAL), "DH_LINK_TYPE_SIGNAL", "signal" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("DhLinkType"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
dh_link_flags_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (DH_LINK_FLAGS_NONE), "DH_LINK_FLAGS_NONE", "none" },
        { C_FLAGS (DH_LINK_FLAGS_DEPRECATED), "DH_LINK_FLAGS_DEPRECATED", "deprecated" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("DhLinkFlags"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

